@@ -34,7 +34,6 @@ enum {
     EXTRACT_EDIDS_OUTPUT_FILE_OPTION,
     MULTI_GPU_OPTION,
     NVIDIA_XINERAMA_INFO_ORDER_OPTION,
-    LOGO_PATH_OPTION,
     METAMODE_ORIENTATION_OPTION,
     VIRTUAL_OPTION,
     USE_DISPLAY_DEVICE_OPTION,
@@ -59,6 +58,9 @@ enum {
     NVIDIA_3DVISION_DISPLAY_TYPE_OPTION,
     RESTORE_ORIGINAL_BACKUP_OPTION,
     NUM_X_SCREENS_OPTION,
+    FORCE_COMPOSITION_PIPELINE_OPTION,
+    FORCE_FULL_COMPOSITION_PIPELINE_OPTION,
+    ALLOW_HMD_OPTION,
 };
 
 /*
@@ -250,13 +252,6 @@ static const NVGetoptOption __options[] = {
       "By default nvidia-xconfig changes the  display  driver  to \"nvidia\" "
       "for all configured X screens; this option preserves the existing driver "
       "name of each X screen." },
-    
-    { "enable-acpi-hotkeys",
-      XCONFIG_BOOL_VAL(ENABLE_ACPI_HOTKEYS_BOOL_OPTION), 
-      NVGETOPT_IS_BOOLEAN, NULL,
-      "The \"EnableACPIHotkeys\" option can be specified to override the "
-      "NVIDIA X driver's default decision to enable or disable ACPI "
-      "display change hotkey events." },
 
     { "enable-all-gpus", 'a', 0, NULL,
       "Configure an X screen on every GPU in the system." },
@@ -350,15 +345,6 @@ static const NVGetoptOption __options[] = {
       "not specified, the first Server Layout in the X configuration "
       "file is used." },
 
-    { "logo",
-      XCONFIG_BOOL_VAL(NOLOGO_BOOL_OPTION), NVGETOPT_IS_BOOLEAN, NULL,
-      "Disable or enable the \"NoLogo\" X configuration option." },
-
-    { "logo-path", LOGO_PATH_OPTION,
-      NVGETOPT_STRING_ARGUMENT | NVGETOPT_ALLOW_DISABLE, "PATH",
-      "Set the path to the PNG file to be used as the logo splash screen at X "
-      "server startup." },
-
     { "mode",
       MODE_OPTION, NVGETOPT_IS_BOOLEAN | NVGETOPT_STRING_ARGUMENT, NULL,
       "Add the specified mode to the mode list." },
@@ -652,13 +638,31 @@ static const NVGetoptOption __options[] = {
       NVGETOPT_IS_BOOLEAN, NULL, "Allow the X server to start even if no "
       "connected display devices could be detected." },
 
-    { "delete-unused-dp12-displays", XCONFIG_BOOL_VAL(DELETE_UNUSED_DP12_DPYS),
-      NVGETOPT_IS_BOOLEAN, NULL, "Delete DisplayPort 1.2 RandR outputs that "
-      "are disconnected and not named in any MetaModes." },
-
     { "inband-stereo-signaling", XCONFIG_BOOL_VAL(INBAND_STEREO_SIGNALING),
       NVGETOPT_IS_BOOLEAN, NULL, "Enable or disable the "
       "\"InbandStereoSignaling\" X configuration option." },
 
+    { "force-yuv-420", XCONFIG_BOOL_VAL(FORCE_YUV_420),
+      NVGETOPT_IS_BOOLEAN, NULL, "Enable or disable the "
+      "\"ForceYUV420\" X configuration option. If the current display and GPU "
+      "both support uncompressed RGB 4:4:4 output and YUV 4:2:0 compressed "
+      "output with the current mode, then RGB 4:4:4 output is selected by "
+      "default. This option forces the use of YUV 4:2:0 output (where "
+      "supported) instead." },
+
+    { "force-composition-pipeline", FORCE_COMPOSITION_PIPELINE_OPTION,
+      NVGETOPT_STRING_ARGUMENT | NVGETOPT_ALLOW_DISABLE, NULL,
+      "Enable or disable the \"ForceCompositionPipeline\" X "
+      "configuration option." },
+
+    { "force-full-composition-pipeline", FORCE_FULL_COMPOSITION_PIPELINE_OPTION,
+      NVGETOPT_STRING_ARGUMENT | NVGETOPT_ALLOW_DISABLE, NULL,
+      "Enable or disable the \"ForceFullCompositionPipeline\" X "
+      "configuration option." },
+
+    { "allow-hmd", ALLOW_HMD_OPTION,
+      NVGETOPT_STRING_ARGUMENT | NVGETOPT_ALLOW_DISABLE, NULL,
+      "Enable or disable the \"AllowHMD\" X configuration option." },
+
     { NULL, 0, 0, NULL, NULL },
 };
