@@ -37,7 +37,6 @@ typedef struct {
 
 static const NvidiaXConfigOption __options[] = {
     
-    { NOLOGO_BOOL_OPTION,                    TRUE,  "NoLogo" },
     { UBB_BOOL_OPTION,                       FALSE, "UBB" },
     { RENDER_ACCEL_BOOL_OPTION,              FALSE, "RenderAccel" },
     { NO_RENDER_EXTENSION_BOOL_OPTION,       TRUE,  "NoRenderExtension" },
@@ -65,12 +64,11 @@ static const NvidiaXConfigOption __options[] = {
     { INCLUDE_IMPLICIT_METAMODES_BOOL_OPTION,FALSE, "IncludeImplicitMetaModes" },
     { USE_EVENTS_BOOL_OPTION,                FALSE, "UseEvents" },
     { CONNECT_TO_ACPID_BOOL_OPTION,          FALSE, "ConnectToAcpid" },
-    { ENABLE_ACPI_HOTKEYS_BOOL_OPTION,       FALSE, "EnableACPIHotkeys" },
     { MODE_DEBUG_BOOL_OPTION,                FALSE, "ModeDebug" },
     { BASE_MOSAIC_BOOL_OPTION,               FALSE, "BaseMosaic" },
     { ALLOW_EMPTY_INITIAL_CONFIGURATION,     FALSE, "AllowEmptyInitialConfiguration" },
-    { DELETE_UNUSED_DP12_DPYS,               FALSE, "DeleteUnusedDP12Displays" },
     { INBAND_STEREO_SIGNALING,               FALSE, "InbandStereoSignaling" },
+    { FORCE_YUV_420,                         FALSE, "ForceYUV420" },
     { 0,                                     FALSE, NULL },
 };
 
@@ -611,16 +609,7 @@ void update_options(Options *op, XConfigScreenPtr screen)
             }
         }
     }
-    
-    /* add the LogoPath option */
 
-    if (op->logo_path) {
-        remove_option(screen, "LogoPath");
-        if (op->logo_path != NV_DISABLE_STRING_OPTION) {
-            set_option_value(screen, "LogoPath", op->logo_path);
-        }
-    }
-   
     /* add the UseDisplayDevice option */
  
     if (op->use_display_device) {
@@ -736,4 +725,33 @@ void update_options(Options *op, XConfigScreenPtr screen)
         }
     }
 
+    /* add the ForceCompositionPipeline option */
+
+    if (op->force_composition_pipeline) {
+        remove_option(screen, "ForceCompositionPipeline");
+        if (op->force_composition_pipeline != NV_DISABLE_STRING_OPTION) {
+            set_option_value(screen, "ForceCompositionPipeline",
+                             op->force_composition_pipeline);
+        }
+    }
+
+    /* add the ForceFullCompositionPipeline option */
+
+    if (op->force_full_composition_pipeline) {
+        remove_option(screen, "ForceFullCompositionPipeline");
+        if (op->force_full_composition_pipeline != NV_DISABLE_STRING_OPTION) {
+            set_option_value(screen, "ForceFullCompositionPipeline",
+                             op->force_full_composition_pipeline);
+        }
+    }
+
+    /* add the AllowHMD option */
+
+    if (op->allow_hmd) {
+        remove_option(screen, "AllowHMD");
+        if (op->allow_hmd != NV_DISABLE_STRING_OPTION) {
+            set_option_value(screen, "AllowHMD", op->allow_hmd);
+        }
+    }
+
 } /* update_options() */
